Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Definition ¶
type Definition struct {
Category string `json:"category"`
Definition string `json:"definition"`
Origin []string `json:"origin"`
Notes []string `json:"notes"`
Examples []string `json:"examples"`
}
Definition represents a single definition for a word, including the category, origin etc.
type Entry ¶
type Entry struct {
Word string `json:"word"`
Etymology string `json:"etymology"`
Definitions []*Definition `json:"definitions"`
Variations []*Variation `json:"variations"`
}
Entry represents a collection of definitions and variations for a given word.
type NotFoundError ¶
type NotFoundError struct {
// contains filtered or unexported fields
}
NotFoundError is a special error type that is returned when the word could not be found in the API.
func (NotFoundError) Error ¶
func (e NotFoundError) Error() string
type Variation ¶
type Variation struct {
Definitions []*Definition `json:"definitions"`
Variation string `json:"variation"`
}
Variation represents an alternative way to use the word, e.g. in a different context.
Click to show internal directories.
Click to hide internal directories.